summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xtoolbin/localcluster/clusterpush.pl14
1 files changed, 12 insertions, 2 deletions
diff --git a/toolbin/localcluster/clusterpush.pl b/toolbin/localcluster/clusterpush.pl
index 1d3bfe31f..07eb21c17 100755
--- a/toolbin/localcluster/clusterpush.pl
+++ b/toolbin/localcluster/clusterpush.pl
@@ -7,7 +7,7 @@ use Data::Dumper;
my $verbose=0;
# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
@@ -23,7 +23,8 @@ my %products=('abort' =>1,
'gpdl'=>1,
'mupdf'=>1,
'mujstest'=>1,
- 'murun'=>1);
+ 'murun'=>1,
+ 'mudrawpy'=>1);
my $user;
my $product="";
@@ -216,6 +217,15 @@ my $cmd="rsync -avxcz ".
" --exclude .tif --exclude .bmp".
" --exclude debug --exclude release --exclude generated --exclude sanitize". # we cannot just exclude build, since tiff/build/Makefile.in, etc. is needed
" --exclude tiff-config".
+" --exclude 'shared-*'".
+
+# Exclude files generated by scripts/mupdfwrap.py:
+" --exclude mupdfwrap_ref".
+" --exclude platform/c++".
+" --exclude platform/python".
+" --exclude include/html".
+" --exclude include/latex".
+
# " --exclude Makefile". We can't just exclude Makefile, since the MuPDF Makefile is not a derived file.
" -e \"$ssh\" ".
" .".
@@ -7,7 +7,7 @@ use Data::Dumper;
my $verbose=0;
-# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
+# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [mudrawpy] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
'gpdl'=>1,